# Mozilla Tracking Protection Tools [![Build Status](https://travis-ci.org/mozilla/trackingprotection-tools.svg?branch=master)](https://travis-ci.org/mozilla/trackingprotection-tools)

A collection of tools for working with and analyzing Firefox's Tracking
Protection.

## Tools

1. **DisconnectParser**: A python parser for the Disconnect Tracking Protection
   list.
2. **DisconnectReporting**: A collection of tools to prepare and send tracking
   domain reports to Disconnect.
